# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## [Unreleased] - yyyy-mm-dd

## [0.0.1] - 2025-11-16

### 🚀 Initial Release - AA Standings Manager

- **0.0.1** (2025-11-16) - Initial release of aa-standingsmanager
